@@ -293,8 +293,9 @@ class attributes:
             spine.set_color(self.workspace_color if isinstance(self.spine_color, type(None)) else self.spine_color)
 
         if not isinstance(self.spines_removed, type(None)):
-            for spine in self.spines_removed:
-                self.ax.spines[["left", "bottom", "top", "right"][spine]].set_visible(False)
+            for i in self.spines_removed:
+                if self.spines_removed[i] == 0:
+                    self.ax.spines[["left", "bottom", "top", "right"][i]].set_visible(False)
 
         # Axis ticks
         left, bottom, top, right = self.ticks_where
